@@ -50,7 +50,7 @@ def set_elastic_vars(__ip__=None, __port__=None, __user__= None, __password__= N
         host= elastic_vars["__ip__"]+":"+str(elastic_vars["__port__"])
         elastic_vars["__es__"] = Elasticsearch([host],
                                                http_auth=(elastic_vars["__user__"],
-                                                          elastic_vars["__password"]))
+                                                          elastic_vars["__password__"]))
     return 1
 
 def login(__username__="", __password__="", __host__="45.56.109.120", __port__=14096, __database__="Sun"):
