@@ -8,7 +8,7 @@ import subprocess
 
 if not util.is_package("es_core_news_md"):
     subprocess.run("python -m spacy download es_core_news_md")
-    print("instalando el modelo de leguanje 'es_core_news_md', el kernel será reiniciado, porfavor vuelva a ejecutar su codigo")
+    print("instalando el modelo de leguanje 'es_core_news_md', porfavor vuelva a importar tools")
 else:  
     nlp = LOAD('es_core_news_md', disable=['parser','ner','textcat','...'] )
     matcher = Matcher(nlp.vocab)
